"use strict";
// Copyright IBM Corp. and LoopBack contributors 2020. All Rights Reserved.
// Node module: @loopback/example-webpack
// This file is licensed under the MIT License.
// License text available at https://opensource.org/licenses/MIT
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const testlab_1 = require("@loopback/testlab");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const puppeteer_1 = tslib_1.__importDefault(require("puppeteer"));
const url_1 = tslib_1.__importDefault(require("url"));
const test_helper_1 = require("./test-helper");
//
/*
 * `zombie` fails to load the html file url with 404 on Windows
 * 1) bundle-web.js
 *       "before all" hook for "should see the page with greetings":
 *     Error: Server returned status code 404 from file:///C:/projects/loopback-next/examples/webpack/index.html
 *      at C:\projects\loopback-next\examples\webpack\node_modules\zombie\lib\document.js:649:15
 *      at process._tickCallback (internal/process/next_tick.js:68:7)
 *
 * See https://github.com/assaf/zombie/issues/915
 */
(0, testlab_1.skipIf)(process.platform === 'win32', // Skip on Windows
describe, 'bundle-web.js', () => {
    before('generate bundle-web.js', async function () {
        // It may take some time to generate the bundle using webpack
        this.timeout(30000);
        await (0, test_helper_1.generateBundle)('web');
        (0, testlab_1.expect)(fs_1.default.existsSync(path_1.default.join(__dirname, '../../bundle-web.js'))).to.be.true();
    });
    let browser;
    let html;
    before(async function () {
        this.timeout(15000);
        browser = await puppeteer_1.default.launch({
            headless: true,
            args: ['--no-sandbox'],
        });
        const page = await browser.newPage();
        await page.goto(url_1.default
            .pathToFileURL(path_1.default.join(__dirname, '../../../index.html'))
            .toString(), { waitUntil: 'networkidle2' });
        html = await page.content();
        /*
        const bodyHandle = await page.$('body');
        html = await page.evaluate(body => body.innerHTML, bodyHandle);
        await bodyHandle!.dispose();
        */
        await browser.close();
    });
    it('should see the page with greetings', () => {
        let body = html;
        body = body.replace(/\[[^\[\]]+\] /g, '');
        (0, testlab_1.expect)(body).to.match(/<li>\(en\) Hello, Jane!<\/li>/);
        (0, testlab_1.expect)(body).to.match(/<li>Hello, John!<\/li>/);
        (0, testlab_1.expect)(body).to.match(/<li>\(zh\) 你好，John！<\/li>/);
        (0, testlab_1.expect)(body).to.match(/<li>\(en\) Hello, Jane!<\/li>/);
    });
});
//# sourceMappingURL=bundle-web.integration.js.map